@@ -44,6 +44,7 @@ def schema():
         },
         'required':['username']
     })
+    return schema
 
 class VerifyError(Exception):
     pass
@@ -108,6 +109,7 @@ def apply(inputhashes, log):
                 args.append('--home')
                 args.append(user['homedir'])
 
+            args.append(username)
             result = subprocess.call(args)
 
             if result != 0:
